==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRouteDestinationFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRouteDestinationFluentImpl<A extends HTTPRouteDestinationFluent<A>> extends BaseFluent<A> implements HTTPRouteDestinationFluent<A>{
  public HTTPRouteDestinationFluentImpl() {
  }
  public HTTPRouteDestinationFluentImpl(HTTPRouteDestination instance) {
    this.withDestination(instance.getDestination()); 
    this.withHeaders(instance.getHeaders()); 
    this.withWeight(instance.getWeight()); 
  }
  private DestinationBuilder destination;
  private HeadersBuilder headers;
  private Integer weight;
  
  /**
   * This method has been deprecated, please use method buildDestination instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getDestination() {
    return this.destination!=null ?this.destination.build():null;
  }
  public Destination buildDestination() {
    return this.destination!=null ?this.destination.build():null;
  }
  public A withDestination(Destination destination) {
    _visitables.get("destination").remove(this.destination);
    if (destination!=null){ this.destination= new DestinationBuilder(destination); _visitables.get("destination").add(this.destination);} else { this.destination = null; _visitables.get("destination").remove(this.destination); } return (A) this;
  }
  public Boolean hasDestination() {
    return this.destination != null;
  }
  public HTTPRouteDestinationFluent.DestinationNested<A> withNewDestination() {
    return new HTTPRouteDestinationFluentImpl.DestinationNestedImpl();
  }
  public HTTPRouteDestinationFluent.DestinationNested<A> withNewDestinationLike(Destination item) {
    return new HTTPRouteDestinationFluentImpl.DestinationNestedImpl(item);
  }
  public HTTPRouteDestinationFluent.DestinationNested<A> editDestination() {
    return withNewDestinationLike(getDestination());
  }
  public HTTPRouteDestinationFluent.DestinationNested<A> editOrNewDestination() {
    return withNewDestinationLike(getDestination() != null ? getDestination(): new DestinationBuilder().build());
  }
  public HTTPRouteDestinationFluent.DestinationNested<A> editOrNewDestinationLike(Destination item) {
    return withNewDestinationLike(getDestination() != null ? getDestination(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public Headers getHeaders() {
    return this.headers!=null ?this.headers.build():null;
  }
  public Headers buildHeaders() {
    return this.headers!=null ?this.headers.build():null;
  }
  public A withHeaders(Headers headers) {
    _visitables.get("headers").remove(this.headers);
    if (headers!=null){ this.headers= new HeadersBuilder(headers); _visitables.get("headers").add(this.headers);} else { this.headers = null; _visitables.get("headers").remove(this.headers); } return (A) this;
  }
  public Boolean hasHeaders() {
    return this.headers != null;
  }
  public HTTPRouteDestinationFluent.HeadersNested<A> withNewHeaders() {
    return new HTTPRouteDestinationFluentImpl.HeadersNestedImpl();
  }
  public HTTPRouteDestinationFluent.HeadersNested<A> withNewHeadersLike(Headers item) {
    return new HTTPRouteDestinationFluentImpl.HeadersNestedImpl(item);
  }
  public HTTPRouteDestinationFluent.HeadersNested<A> editHeaders() {
    return withNewHeadersLike(getHeaders());
  }
  public HTTPRouteDestinationFluent.HeadersNested<A> editOrNewHeaders() {
    return withNewHeadersLike(getHeaders() != null ? getHeaders(): new HeadersBuilder().build());
  }
  public HTTPRouteDestinationFluent.HeadersNested<A> editOrNewHeadersLike(Headers item) {
    return withNewHeadersLike(getHeaders() != null ? getHeaders(): item);
  }
  public Integer getWeight() {
    return this.weight;
  }
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  public Boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPRouteDestinationFluentImpl that = (HTTPRouteDestinationFluentImpl) o;
    if (destination != null ? !destination.equals(that.destination) :that.destination != null) return false;
    if (headers != null ? !headers.equals(that.headers) :that.headers != null) return false;
    if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destination,  headers,  weight,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (headers != null) { sb.append("headers:"); sb.append(headers + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  class DestinationNestedImpl<N> extends DestinationFluentImpl<HTTPRouteDestinationFluent.DestinationNested<N>> implements HTTPRouteDestinationFluent.DestinationNested<N>,Nested<N>{
    DestinationNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DestinationNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) HTTPRouteDestinationFluentImpl.this.withDestination(builder.build());
    }
    public N endDestination() {
      return and();
    }
    
  }
  class HeadersNestedImpl<N> extends HeadersFluentImpl<HTTPRouteDestinationFluent.HeadersNested<N>> implements HTTPRouteDestinationFluent.HeadersNested<N>,Nested<N>{
    HeadersNestedImpl(Headers item) {
      this.builder = new HeadersBuilder(this, item);
    }
    HeadersNestedImpl() {
      this.builder = new HeadersBuilder(this);
    }
    HeadersBuilder builder;
    public N and() {
      return (N) HTTPRouteDestinationFluentImpl.this.withHeaders(builder.build());
    }
    public N endHeaders() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPRouteDestinationFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRouteDestinationFluentImpl<A extends HTTPRouteDestinationFluent<A>> extends BaseFluent<A> implements HTTPRouteDestinationFluent<A>{
  public HTTPRouteDestinationFluentImpl() {
  }
  public HTTPRouteDestinationFluentImpl(HTTPRouteDestination instance) {
    if (instance != null) {
      this.withDestination(instance.getDestination());
      this.withHeaders(instance.getHeaders());
      this.withWeight(instance.getWeight());
    }
  }
  private DestinationBuilder destination;
  private HeadersBuilder headers;
  private Integer weight;
  
  /**
   * This method has been deprecated, please use method buildDestination instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getDestination() {
    return this.destination!=null ?this.destination.build():null;
  }
  public Destination buildDestination() {
    return this.destination!=null ?this.destination.build():null;
  }
  public A withDestination(Destination destination) {
    _visitables.get("destination").remove(this.destination);
    if (destination!=null){ this.destination= new DestinationBuilder(destination); _visitables.get("destination").add(this.destination);} else { this.destination = null; _visitables.get("destination").remove(this.destination); } return (A) this;
  }
  public Boolean hasDestination() {
    return this.destination != null;
  }
  public HTTPRouteDestinationFluentImpl.DestinationNested<A> withNewDestination() {
    return new HTTPRouteDestinationFluentImpl.DestinationNestedImpl();
  }
  public HTTPRouteDestinationFluentImpl.DestinationNested<A> withNewDestinationLike(Destination item) {
    return new HTTPRouteDestinationFluentImpl.DestinationNestedImpl(item);
  }
  public HTTPRouteDestinationFluentImpl.DestinationNested<A> editDestination() {
    return withNewDestinationLike(getDestination());
  }
  public HTTPRouteDestinationFluentImpl.DestinationNested<A> editOrNewDestination() {
    return withNewDestinationLike(getDestination() != null ? getDestination(): new DestinationBuilder().build());
  }
  public HTTPRouteDestinationFluentImpl.DestinationNested<A> editOrNewDestinationLike(Destination item) {
    return withNewDestinationLike(getDestination() != null ? getDestination(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildHeaders instead.
   * @return The buildable object.
   */
  @Deprecated
  public Headers getHeaders() {
    return this.headers!=null ?this.headers.build():null;
  }
  public Headers buildHeaders() {
    return this.headers!=null ?this.headers.build():null;
  }
  public A withHeaders(Headers headers) {
    _visitables.get("headers").remove(this.headers);
    if (headers!=null){ this.headers= new HeadersBuilder(headers); _visitables.get("headers").add(this.headers);} else { this.headers = null; _visitables.get("headers").remove(this.headers); } return (A) this;
  }
  public Boolean hasHeaders() {
    return this.headers != null;
  }
  public HTTPRouteDestinationFluentImpl.HeadersNested<A> withNewHeaders() {
    return new HTTPRouteDestinationFluentImpl.HeadersNestedImpl();
  }
  public HTTPRouteDestinationFluentImpl.HeadersNested<A> withNewHeadersLike(Headers item) {
    return new HTTPRouteDestinationFluentImpl.HeadersNestedImpl(item);
  }
  public HTTPRouteDestinationFluentImpl.HeadersNested<A> editHeaders() {
    return withNewHeadersLike(getHeaders());
  }
  public HTTPRouteDestinationFluentImpl.HeadersNested<A> editOrNewHeaders() {
    return withNewHeadersLike(getHeaders() != null ? getHeaders(): new HeadersBuilder().build());
  }
  public HTTPRouteDestinationFluentImpl.HeadersNested<A> editOrNewHeadersLike(Headers item) {
    return withNewHeadersLike(getHeaders() != null ? getHeaders(): item);
  }
  public Integer getWeight() {
    return this.weight;
  }
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  public Boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRouteDestinationFluentImpl that = (HTTPRouteDestinationFluentImpl) o;
    if (!java.util.Objects.equals(destination, that.destination)) return false;

    if (!java.util.Objects.equals(headers, that.headers)) return false;

    if (!java.util.Objects.equals(weight, that.weight)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(destination,  headers,  weight,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destination != null) { sb.append("destination:"); sb.append(destination + ","); }
    if (headers != null) { sb.append("headers:"); sb.append(headers + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  class DestinationNestedImpl<N> extends DestinationFluentImpl<HTTPRouteDestinationFluentImpl.DestinationNested<N>> implements HTTPRouteDestinationFluentImpl.DestinationNested<N>,Nested<N>{
    DestinationNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DestinationNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) HTTPRouteDestinationFluentImpl.this.withDestination(builder.build());
    }
    public N endDestination() {
      return and();
    }
    
  }
  class HeadersNestedImpl<N> extends HeadersFluentImpl<HTTPRouteDestinationFluentImpl.HeadersNested<N>> implements HTTPRouteDestinationFluentImpl.HeadersNested<N>,Nested<N>{
    HeadersNestedImpl(Headers item) {
      this.builder = new HeadersBuilder(this, item);
    }
    HeadersNestedImpl() {
      this.builder = new HeadersBuilder(this);
    }
    HeadersBuilder builder;
    public N and() {
      return (N) HTTPRouteDestinationFluentImpl.this.withHeaders(builder.build());
    }
    public N endHeaders() {
      return and();
    }
    
  }
  
}
